"use strict";

var _getFieldFromLang = _interopRequireDefault(require("./getFieldFromLang"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
 * Author: Andrieiev Danil |  danssg08@gmail.com | https://github.com/DanilAndreev
 * Copyright (C) 2020.
 */
describe("Utils -> getFieldFromLang", function () {
  test("Check basic work", function () {
    var lang = {
      name: "en-us",
      label: "English",
      locale: {
        hello: {
          darkness: "Hello darkness ny old friend!"
        }
      }
    };
    var expected = lang.locale.hello.darkness;
    expect((0, _getFieldFromLang.default)(lang, "hello/darkness")).toBe(expected);
  });
  test("Make function to throw TypeError when lang is not defined", function () {
    expect(function () {
      return (0, _getFieldFromLang.default)(null, "hello/darkness");
    }).toThrow(TypeError);
  });
  test("Make function to throw TypeError when lang.locale is not defined", function () {
    var lang = {
      name: "en-us",
      label: "English"
    };
    expect(function () {
      return (0, _getFieldFromLang.default)(lang, "hello/darkness");
    }).toThrow(TypeError);
  });
  test("Try to access missing field", function () {
    var lang = {
      name: "en-us",
      label: "English",
      locale: {
        hello: {
          darkness: "Hello darkness ny old friend!"
        }
      }
    };
    var expected = lang.locale.hello.darkness;
    expect((0, _getFieldFromLang.default)(lang, "hello/boy/man/kek")).toBe(undefined);
  });
});